;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "claude-code" "20260526.1329"
  "Run Claude Code sessions."
  '((emacs         "28.1")
    (projectile    "2.5.0")
    (vterm         "0.0.2")
    (transient     "0.4.0")
    (markdown-mode "2.5"))
  :url "https://github.com/yuya373/claude-code-emacs"
  :commit "4d460e2fa56e6919a9fc4f9b985592a983f9f724"
  :revdesc "4d460e2fa56e"
  :keywords '("tools" "convenience"))
